@@ -4,12 +4,12 @@ modavg <-
 
     mod.avg <- NULL
     known <- rep(0, 5) #create an identifier of class type other than lm, glm, or lme
-#extract classes
+##extract classes
     mod.class <- unlist(lapply(X=cand.set, FUN=class))
-#check if all are identical
+##check if all are identical
     check.class <- unique(mod.class)
 
-#determine if lm or glm  
+##determine if lm or glm  
     if(identical(check.class, "lm") || identical(check.class, c("glm", "lm"))) {
       mod.avg <- modavg.glm(cand.set=cand.set, parm=parm, modnames=modnames, c.hat=c.hat, gamdisp=gamdisp,
                             conf.level=conf.level, second.ord=second.ord, nobs=nobs, exclude=exclude,
@@ -18,7 +18,7 @@ modavg <-
     }   
 
 
-#determine if multinom
+##determine if multinom
     if(identical(check.class, c("multinom", "nnet"))) {
       mod.avg <- modavg.mult(cand.set=cand.set, parm=parm, modnames=modnames, c.hat=c.hat,
                              conf.level=conf.level, second.ord=second.ord, nobs=nobs, exclude=exclude,
@@ -37,7 +37,7 @@ modavg <-
       
 
     
-#determine if lme
+##determine if lme
     if(identical(check.class, "lme"))  {
       mod.avg <- modavg.lme(cand.set=cand.set, parm=parm, modnames=modnames,
                             conf.level=conf.level, second.ord=second.ord, exclude=exclude,
@@ -46,7 +46,7 @@ modavg <-
     }      
 
 
-#warn if models are from a mixture of model classes
+##warn if models are from a mixture of model classes
     if(identical(sort(check.class), c("lm", "lme"))) {
       stop(cat("Function not appropriate for mixture of object classes:", "\n",
                "avoid mixing objects of classes lm and lme", "\n"))
@@ -54,11 +54,16 @@ modavg <-
     }
 
 
-#warn if class is neither lm, glm, multinom, polr, or lme
+##warn if class is neither lm, glm, multinom, polr, or lme
     if(sum(known) < 1) {stop("Function not defined for this object class")}
 
 
-#if(class(mod)[1]=="nlm") {mod.avg <- modavg.nlm(cand.set, parm, modnames, c.hat)}      #determine if object from nlm optimizer
+##warn if exclude is neither a list nor NULL
+    if(!is.null(exclude)) {
+      if(!is.list(exclude)) {stop("Items in \"exclude\" must be specified as a list")}
+    }
+
+##if(class(mod)[1]=="nlm") {mod.avg <- modavg.nlm(cand.set, parm, modnames, c.hat)}      #determine if object from nlm optimizer
     return(mod.avg)
 
 
@@ -71,18 +76,18 @@ print.modavg <-
     cat("\nMultimodel inference on \"", x$Parameter, "\" based on", ic, "\n")
     cat("\n", ic, "table used to obtain model-averaged estimate:\n")
     oldtab <- x$Mod.avg.table
-    if (ncol(oldtab) > 9) {cat("\t(c-hat estimate = ", oldtab$c_hat[1], ")\n")}
+    if (any(names(oldtab)=="c_hat")) {cat("\t(c-hat estimate = ", oldtab$c_hat[1], ")\n")}
     cat("\n")
-    if (ncol(oldtab) > 9) {
+    if (any(names(oldtab)=="c_hat")) {
       nice.tab <- cbind(oldtab[,2], oldtab[,3], oldtab[,4], oldtab[,6],
-                        oldtab[,7], oldtab[,9], oldtab[,10])
+                        oldtab[,9], oldtab[,10])
     } else {nice.tab <- cbind(oldtab[,2], oldtab[,3], oldtab[,4], oldtab[,6],
-                              oldtab[,7], oldtab[,8], oldtab[,9])
+                              oldtab[,8], oldtab[,9])
           }
 
-#modify printing style if multinomial model is used  
+##modify printing style if multinomial model is used  
     if(length(x$Mod.avg.beta)==1) {
-      colnames(nice.tab) <- c(colnames(oldtab)[c(2,3,4,6,7)], "Estimate", "SE")
+      colnames(nice.tab) <- c(colnames(oldtab)[c(2,3,4,6)], "Estimate", "SE")
       rownames(nice.tab) <- oldtab[,1]
       print(round(nice.tab, digits=digits))
       cat("\nModel-averaged estimate:", eval(round(x$Mod.avg.beta, digits=digits)), "\n")
@@ -90,8 +95,9 @@ print.modavg <-
       cat("",x$Conf.level*100, "% Unconditional confidence interval:", round(x$Lower.CL, digits=digits),
           ",", round(x$Upper.CL, digits=digits), "\n\n")
     } else {
-      nice.tab <- nice.tab[,-c(6,7)]
-      colnames(nice.tab) <- c(colnames(oldtab)[c(2,3,4,6,7)])
+      col.ns <- ncol(nice.tab)
+      nice.tab <- nice.tab[,-c(col.ns-1,col.ns)]
+      colnames(nice.tab) <- c(colnames(oldtab)[c(2,3,4,6)])
       rownames(nice.tab) <- oldtab[,1]
       print(round(nice.tab, digits=digits))
       cat("\n\nModel-averaged estimates for different levels of response variable:", "\n\n")
