@@ -1,5 +1,6 @@
 modavgpred <-
-function(cand.set, modnames, newdata, type="response", c.hat=1, gamdisp=NULL, second.ord=TRUE, nobs=NULL) {
+function(cand.set, modnames, newdata, type = "response", c.hat = 1, gamdisp = NULL, second.ord = TRUE,
+         nobs = NULL, uncond.se = "revised") {
 #newdata is data frame with exact structure of the original data frame (same variable names and type)
 if(type=="terms") {stop("The terms argument is not defined for this function")}
 dispersion <- c.hat
@@ -14,6 +15,17 @@ if(c.hat>1 && !is.null(gamdisp)) {stop("You cannot specify values for both c.hat
   mod.class <- unlist(lapply(X=cand.set, FUN=class))
 #check if all are identical
   check.class <- unique(mod.class)
+
+#check that link function is the same for all models if linear predictor is used
+if(identical(type, "link")) {
+  check.link <- unlist(lapply(X = cand.set, FUN=function(i) i$family$link))
+  unique.link <- unique(x=check.link)
+  if(length(unique.link) > 1) {stop(cat("It is not appropriate to compute a model averaged beta estimate\n",
+"with different link functions\n"))}
+}
+
+
+
   
   if(identical(check.class, "lm") || identical(check.class, c("glm", "lm")))  {
 
@@ -27,15 +39,20 @@ AICctab<-aictab(cand.set=cand.set, modnames=modnames, c.hat=c.hat, second.ord=se
 Mod.avg.out<-matrix(NA, nrow=nobs, ncol=2)
 colnames(Mod.avg.out)<-c("Mod.avg.est", "Uncond.SE")
 
+
+
+
 #begin loop - AICc
 if(second.ord==TRUE && c.hat==1){
   for (obs in 1:nobs) {
 
 #extract fitted value for observation obs
 fit<-unlist(lapply(X=cand.set, FUN=function(i)predict(i, se.fit=TRUE, newdata=newdata[obs, ], type=type, dispersion=dispersion)$fit))
+
 #extract SE for fitted value for observation obs
 SE<-unlist(lapply(X=cand.set, FUN=function(i)predict(i, se.fit=TRUE, newdata=newdata[obs, ], type=type, dispersion=dispersion)$se.fit))
 
+
 #create temporary data.frame to store fitted values and SE 
 AICctmp<-AICctab
 AICctmp$fit<-fit
@@ -44,9 +61,20 @@ AICctmp$SE<-SE
 #compute model averaged prediction and store in output matrix
 Mod.avg.out[obs, 1]<-sum(AICctmp$AICcWt*AICctmp$fit)
 #compute unconditional SE and store in output matrix
-Mod.avg.out[obs, 2]<-sum(AICctmp$AICcWt*sqrt(AICctmp$SE^2 + (AICctmp$fit- Mod.avg.out[obs, 1])^2))
+
+#unconditional SE based on equation 4.9 of Burnham and Anderson 2002
+if(identical(uncond.se, "old")) {
+  Mod.avg.out[obs, 2]<-sum(AICctmp$AICcWt*sqrt(AICctmp$SE^2 + (AICctmp$fit- Mod.avg.out[obs, 1])^2))
+}
+
+#revised computation of unconditional SE based on equation 6.12 of Burnham and Anderson 2002; Anderson 2008, p. 111
+if(identical(uncond.se, "revised")) {
+  Mod.avg.out[obs, 2]<-sqrt(sum(AICctmp$AICcWt*(AICctmp$SE^2 + (AICctmp$fit- Mod.avg.out[obs, 1])^2)))
 }
 }
+}
+
+
 
 
 #create temporary data.frame to store fitted values and SE - QAICc
@@ -64,10 +92,21 @@ QAICctmp$SE<-SE
 
 #compute model averaged prediction and store in output matrix
 Mod.avg.out[obs, 1]<-sum(QAICctmp$QAICcWt*QAICctmp$fit)
+
 #compute unconditional SE and store in output matrix
+#unconditional SE based on equation 4.9 of Burnham and Anderson 2002
+if(identical(uncond.se, "old")) {
 Mod.avg.out[obs, 2]<-sum(QAICctmp$QAICcWt*sqrt(QAICctmp$SE^2 + (QAICctmp$fit- Mod.avg.out[obs, 1])^2))
 }
+
+#revised computation of unconditional SE based on equation 6.12 of Burnham and Anderson 2002; Anderson 2008, p. 111
+if(identical(uncond.se, "revised")) {
+Mod.avg.out[obs, 2]<-sqrt(sum(QAICctmp$QAICcWt*(QAICctmp$SE^2 + (QAICctmp$fit- Mod.avg.out[obs, 1])^2)))  
 }
+}
+}
+
+
 
 
 #create temporary data.frame to store fitted values and SE - AIC
@@ -85,10 +124,23 @@ AICtmp$SE<-SE
 
 #compute model averaged prediction and store in output matrix
 Mod.avg.out[obs, 1]<-sum(AICtmp$AICWt*AICtmp$fit)
+
 #compute unconditional SE and store in output matrix
+#unconditional SE based on equation 4.9 of Burnham and Anderson 2002
+if(identical(uncond.se, "old")) {
 Mod.avg.out[obs, 2]<-sum(AICtmp$AICWt*sqrt(AICtmp$SE^2 + (AICtmp$fit- Mod.avg.out[obs, 1])^2))
 }
+
+#revised computation of unconditional SE based on equation 6.12 of Burnham and Anderson 2002; Anderson 2008, p. 111
+if(identical(uncond.se, "revised")) {
+Mod.avg.out[obs, 2]<-sqrt(sum(AICtmp$AICWt*(AICtmp$SE^2 + (AICtmp$fit- Mod.avg.out[obs, 1])^2)))
+}  
+
 }
+}
+
+
+
 
 #create temporary data.frame to store fitted values and SE - QAIC
 if(second.ord==FALSE && c.hat > 1) {
@@ -105,10 +157,20 @@ QAICtmp$SE<-SE
 
 #compute model averaged prediction and store in output matrix
 Mod.avg.out[obs, 1]<-sum(QAICtmp$QAICWt*QAICtmp$fit)
+
 #compute unconditional SE and store in output matrix
+if(identical(uncond.se, "old")) {
 Mod.avg.out[obs, 2]<-sum(QAICtmp$QAICWt*sqrt(QAICtmp$SE^2 + (QAICtmp$fit- Mod.avg.out[obs, 1])^2))
 }
+
+#revised computation of unconditional SE based on equation 6.12 of Burnham and Anderson 2002; Anderson 2008, p. 111
+if(identical(uncond.se, "revised")) {
+Mod.avg.out[obs, 2]<-sqrt(sum(QAICtmp$QAICWt*(QAICtmp$SE^2 + (QAICtmp$fit- Mod.avg.out[obs, 1])^2)))
+}  
+
 }
+}
+
 
 Mod.pred.list <- list("type" = type, "mod.avg.pred" = Mod.avg.out[,1], "uncond.se" = Mod.avg.out[,2])
 class(Mod.pred.list) <- c("modavgpred", "list")
@@ -117,7 +179,7 @@ return(Mod.pred.list)
 } else {stop("This function is only appropriate with either \'lm\' or \'glm\' classes\n")}
 }
 
-print.modavgpred <- function(x, digits = 4, ...) {
+print.modavgpred <- function(x, digits = 2, ...) {
   cat("\nModel-averaged predictions on the", x$type, "scale based on entire model set:\n\n")
   nice.tab <- cbind(x$mod.avg.pred, x$uncond.se)
   colnames(nice.tab) <- c("mod.avg.pred", "uncond.se")
